@@ -42,6 +42,9 @@ setMethod("import.chain", "ANY", function(con, ...) {
 setMethod("import", "ChainFile", function(con, format, text, exclude = "_") {
   if (!missing(format))
     checkArgFormat(con, format)
+  if (!is(connection(con), "file")) {
+    stop("chain import currently only handles local, uncompressed files")
+  }
   .Call("readChain", path.expand(path(con)), as.character(exclude),
         PACKAGE="rtracklayer")
 })
@@ -99,7 +102,7 @@ setMethod("liftOver", c("GenomicRanges", "Chain"),
               GRanges(spaces,
                       IRanges(start(r) - offsets, end(r) - offsets),
                       strand = strand,
-                      values(gr)[queryHits(ol),])
+                      values(gr)[queryHits(ol),,drop=FALSE])
             }
             rl <- split(x, seqnames(x), drop = TRUE)
             unchainedNames <- setdiff(names(rl), names(chain))
@@ -109,9 +112,9 @@ setMethod("liftOver", c("GenomicRanges", "Chain"),
             sharedNames <- intersect(names(rl), names(chain))
             ind <- split(seq_len(length(x)),
                          as.vector(seqnames(x)))[sharedNames]
-            lifted <- unlist(mseqapply(liftOverSpace, rl[sharedNames],
-                                       chain[sharedNames], ind),
-                             use.names=FALSE)
+            liftedList <- mapply(liftOverSpace, rl[sharedNames],
+                                 chain[sharedNames], ind, SIMPLIFY=FALSE)
+            lifted <- unlist(GRangesList(liftedList), use.names=FALSE)
             split(lifted,
                   factor(unlist(ind, use.names=FALSE), seq_len(length(x))))
           })
