@@ -225,10 +225,12 @@ setMethod("import.gff", "ANY",
       attrList <- list(group = factor(attrCol, levels=unique(attrCol)))
     else attrList <- list()
   } else {
+    if (length(attrCol) == 0L)
+        return(list())
     sentinel <- "\b"
     con <- file()
     on.exit(close(con))
-    writeLines(paste0(sub(";$", "", attrCol), sentinel), con)
+    writeLines(paste0(sub("; *$", "", attrCol), sentinel), con)
     attrs <- scan(con, what=character(),
                   strip.white = TRUE, quiet = TRUE, sep = ";",
                   quote = if (is(file, "GFF3File")) "" else "\"")
@@ -292,6 +294,16 @@ setMethod("import", "GFFFile",
               con <- asGFFVersion(con, match.arg(version))
             asRangedData <- normarg_asRangedData(asRangedData, "import")
 
+            ## download the file first if it's remote
+            if (is.character(resource(con))) {
+                uri <- .parseURI(resource(con))
+                if (uri$scheme %in% c("ftp", "http")) {
+                    destfile <- tempfile()
+                    download.file(resource(con), destfile)
+                    con@resource <- destfile
+                }
+            }
+
             sniffed <- sniffGFFVersion(resource(con))
             version <- gffFileVersion(con)
             if (!length(version)) {
@@ -399,6 +411,12 @@ setGeneric("import.gff3",
 setMethod("import.gff3", "ANY",
           function(con, ...) import(con, "gff3", ...))
 
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### DNAStringSet from fasta data
+###
+
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Coercion
 ###
@@ -447,6 +465,8 @@ scanGFFDirectives <- function(con, tag = NULL) {
         directives <- c(directives, line)
     }
     line <- readLines(con, n = 1)
+    if (length(line) == 0L)
+        break
     lines <- c(lines, line)
   }
   pushBack(lines, con)
