@@ -9,16 +9,21 @@ setClass("UCSCSession",
 # gets an 'hgsid' to initialize the session
 setMethod("initialize", "UCSCSession",
           function(.Object, url = "http://genome.ucsc.edu/cgi-bin/",
-                   user = NULL, session = NULL, ...)
+                   user = NULL, session = NULL, force = FALSE, ...)
           {
             .Object@url <- url
             .Object@views <- new.env()
-            handle <- getCurlHandle(followLocation=TRUE, ...)
-            gw <- getURL(ucscURL(.Object, "gateway"), cookiefile = tempfile(),
-                         header = TRUE, curl = handle)
-            if (grepl("Location: [^[:space:]]+cgi-bin/", gw))
-              .Object@url <-
-                sub(".*Location: ([^[:space:]]+cgi-bin/).*", "\\1", gw)
+            gwURL <- ucscURL(.Object, "gateway")
+            if (force) {
+              gwURL <- paste0(gwURL, '?redirect="manual"')
+            }
+            gw <- httpGet(gwURL, cookiefile = tempfile(), header = TRUE,
+                          .parse=FALSE, ...)
+            if (grepl("redirectTd", gw)) {
+              url <- sub(".*?a href=\"h([^[:space:]]+cgi-bin/).*", "h\\1", gw)
+              return(initialize(.Object, url, user=user, session=session,
+                                force=TRUE, ...))
+            }
             cookie <- grep("Set-[Cc]ookie: hguid[^=]*=", gw)
             if (!length(cookie))
               stop("Failed to obtain 'hguid' cookie")
@@ -524,11 +529,9 @@ ucscExport <- function(object)
 }
 
 setMethod("track", "UCSCSession",
-          function(object, name, range = base::range(object), table = NULL,
-                   asRangedData = FALSE)
+          function(object, name, ...)
           {
-            asRangedData <- normarg_asRangedData(asRangedData, "track")
-            track(ucscTableQuery(object, name, range, table), asRangedData)
+            track(ucscTableQuery(object, track=name, ...))
           })
 
 inconsistentFieldCounts <- function(x) {
@@ -1096,8 +1099,9 @@ setClass("UCSCData",
          "GRanges")
 
 UCSCData <- function(ranges, trackLine = NULL) {
-  metadata(ranges)$trackLine <- trackLine
-  as(ranges, "UCSCData")
+  ucsc <- as(ranges, "UCSCData")
+  ucsc@trackLine <- trackLine
+  ucsc
 }
 
 setMethod("show", "UCSCData",
@@ -1280,9 +1284,9 @@ setMethod("export", c("UCSCData", "UCSCFile"),
               strand <- as.character(strand(object))
               strand[is.na(strand)] <- "NA"
               isStrandDisjoint <- function(track) {
-                all(unlist(tapply(ranges(track), seqnames(track), function(r) {
+                all(tapply(ranges(track), seqnames(track), function(r) {
                   isDisjoint(r) && all(width(r) > 0)
-                })))
+                }), na.rm=TRUE)
               }
               if (!all(unlist(lapply(split(object, strand), isStrandDisjoint))))
               {
@@ -1550,8 +1554,20 @@ setMethod("ucscTrackModes", "ucscTracks",
           })
 
 ## List available UCSC genomes
+.getOrganism <- function(db){
+  .ucsc <- "http://genome.ucsc.edu/cgi-bin"
+  .tryQuery <- function(url, query)
+    tryCatch({
+      htmlTreeParse(url, useInternalNodes=TRUE)[[query]]
+    }, error=function(err) {
+      warning(conditionMessage(err))
+      NA_character_
+    })
+  urls <- sprintf("%s/hgGateway?db=%s", .ucsc, db)
+  sapply(urls, .tryQuery, "string(//div[@id='sectTtl']/i)")
+}
 
-ucscGenomes <- function() {
+ucscGenomes <- function(organism=FALSE) {
   url <- "http://genome.ucsc.edu/FAQ/FAQreleases"
   doc <- httpGet(url)
   table <- getNodeSet(doc, "//table[@class='descTbl']")[[1L]]
@@ -1587,6 +1603,8 @@ ucscGenomes <- function() {
   not_empty <- df$species != ""
   df$species <- rep.int(df$species[not_empty], diff(which(c(not_empty, TRUE))))
   df <- df[df$status == "Available", -5L]
+  if (organism)
+    df$organism <- .getOrganism(df$db)
   rownames(df) <- NULL
   df
 }
@@ -1701,6 +1719,7 @@ setMethod("ucscForm", "UCSCTableQuery",
             if (!is.null(object@outputType)) {
               form <- c(form, hgta_outputType = object@outputType)
             }
+            form$hgta_compressType <- "none" # TODO: support gzip
             form
           })
 
